==> lxqt-session_0.9.0+20150807.orig.tar.xz: lxqt-session-0.9.0+20150807/lxqt-config-session/translations/lxqt-config-session_hu_HU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hu_HU">
<context>
    <name>AutoStartEdit</name>
    <message>
        <location filename="../autostartedit.ui" line="14"/>
        <source>Edit</source>
        <translation>Szerkesztés</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="20"/>
        <source>Name:</source>
        <translation>Név:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="27"/>
        <source>Search...</source>
        <translation>Keresés...</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="47"/>
        <source>Command:</source>
        <translation>Parancs:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="57"/>
        <source>Wait for system tray</source>
        <translation>Várakozás a paneltálcára</translation>
    </message>
    <message>
        <location filename="../autostartedit.cpp" line="59"/>
        <source>Select Application</source>
        <translation>Alkalmazás kiválasztása</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <location filename="../autostartmodel.cpp" line="177"/>
        <source>Global Autostart</source>
        <translation>Automatikus indítás</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="179"/>
        <source>LXQt Autostart</source>
        <translation>LXQt automatikus indítás</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="197"/>
        <source>Location: %1</source>
        <translation>Hely: %1</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="199"/>
        <source>Overrides: %1</source>
        <translation>Felülbírálások: %1</translation>
    </message>
</context>
<context>
    <name>AutoStartPage</name>
    <message>
        <location filename="../autostartpage.ui" line="17"/>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="24"/>
        <source>Add</source>
        <translation>Hozzáadás</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="31"/>
        <source>Edit</source>
        <translation>Szerkesztés</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="44"/>
        <source>Application Autostart</source>
        <translation>Alkalmazás automatikus indítása</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="82"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="82"/>
        <source>File &apos;%1&apos; already exists!</source>
        <translation>Van már &apos;%1&apos; fájl!</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Window Manager</source>
        <translation>Ablakkezelő</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <source>Search...</source>
        <translation>Keresés...</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="59"/>
        <source>LXQt Modules</source>
        <translation>LXQt modulok</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="65"/>
        <source>Start</source>
        <translation>Indítás</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="72"/>
        <source>Stop</source>
        <translation>Leállítás</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="111"/>
        <source>Leave Session</source>
        <translation>Munkamenet elhagyása</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="117"/>
        <source>Ask confirmation to leave session</source>
        <translation>Jóváhagyás az elhagyás előtt</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Alapbeállítások</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="84"/>
        <source>Select a window manager</source>
        <translation>Ablakkezelő választása</translation>
    </message>
</context>
<context>
    <name>DefaultApps</name>
    <message>
        <location filename="../defaultappspage.cpp" line="72"/>
        <source>Select a terminal emulator</source>
        <translation>Terminálemulátor választása</translation>
    </message>
    <message>
        <location filename="../defaultappspage.cpp" line="77"/>
        <source>Select a web browser</source>
        <translation>Webböngésző választása</translation>
    </message>
</context>
<context>
    <name>DefaultAppsPage</name>
    <message>
        <location filename="../defaultappspage.ui" line="23"/>
        <source>Default Applications</source>
        <translation>Alapértelmezett alkalmazások</translation>
    </message>
    <message>
        <location filename="../defaultappspage.ui" line="32"/>
        <source>Terminal Emulation:</source>
        <translation>Terminálemuláció:</translation>
    </message>
    <message>
        <location filename="../defaultappspage.ui" line="52"/>
        <location filename="../defaultappspage.ui" line="79"/>
        <source>Search...</source>
        <translation>Keresés…</translation>
    </message>
    <message>
        <location filename="../defaultappspage.ui" line="59"/>
        <source>Web Browser:</source>
        <translation>Webböngésző:</translation>
    </message>
</context>
<context>
    <name>EnvironmentPage</name>
    <message>
        <location filename="../environmentpage.ui" line="30"/>
        <source>Add</source>
        <translation>Hozzáadás</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="37"/>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="63"/>
        <source>Environment Variables (Advanced)</source>
        <translation>Környezeti változók (speciális)</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="74"/>
        <source>Variable Name</source>
        <translation>Változónév</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="79"/>
        <source>Value</source>
        <translation>Érték</translation>
    </message>
</context>
<context>
    <name>ModuleModel</name>
    <message>
        <location filename="../modulemodel.cpp" line="85"/>
        <source>Running</source>
        <translation>Futó</translation>
    </message>
</context>
<context>
    <name>SessionConfigWindow</name>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="43"/>
        <source>LXQt Session Settings</source>
        <translation>LxQt munkamenet-beállítás</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="46"/>
        <source>Basic Settings</source>
        <translation>Alapbeállítások</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="52"/>
        <source>Default Applications</source>
        <translation>Alapértelmezett alkalmazások</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="55"/>
        <source>Autostart</source>
        <translation>Automatikus indítás</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="60"/>
        <source>Environment (Advanced)</source>
        <translation>Környezet (speciális)</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="84"/>
        <source>Session Restart Required</source>
        <translation>A munkamenet újraindítandó</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="85"/>
        <source>You need to restart desktop session (lxqt-session) to reload settings. Use logout from the main menu.</source>
        <translation>Újra kell indítania a munkamenetet (lxqt-session) a beállítások újratöltéséhez. Használja a főmenü kijelentkezés pontját.</translation>
    </message>
</context>
</TS>

==> lxqt-session-0.10.0.tar.xz: lxqt-session-0.10.0/lxqt-config-session/translations/lxqt-config-session_hu_HU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu_HU">
<context>
    <name>AutoStartEdit</name>
    <message>
        <location filename="../autostartedit.ui" line="14"/>
        <source>Edit</source>
        <translation>Szerkesztés</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="20"/>
        <source>Name:</source>
        <translation>Név:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="27"/>
        <source>Search...</source>
        <translation>Keresés...</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="47"/>
        <source>Command:</source>
        <translation>Parancs:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="57"/>
        <source>Wait for system tray</source>
        <translation>Várakozás a paneltálcára</translation>
    </message>
    <message>
        <location filename="../autostartedit.cpp" line="59"/>
        <source>Select Application</source>
        <translation>Alkalmazás kiválasztása</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <location filename="../autostartmodel.cpp" line="192"/>
        <source>Global Autostart</source>
        <translation>Automatikus indítás</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="194"/>
        <source>LXQt Autostart</source>
        <translation>LXQt automatikus indítás</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="212"/>
        <source>Location: %1</source>
        <translation>Hely: %1</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="214"/>
        <source>Overrides: %1</source>
        <translation>Felülbírálások: %1</translation>
    </message>
</context>
<context>
    <name>AutoStartPage</name>
    <message>
        <location filename="../autostartpage.ui" line="17"/>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="24"/>
        <source>Add</source>
        <translation>Hozzáadás</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="31"/>
        <source>Edit</source>
        <translation>Szerkesztés</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="44"/>
        <source>Application Autostart</source>
        <translation>Alkalmazás automatikus indítása</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="141"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="141"/>
        <source>File &apos;%1&apos; already exists!</source>
        <translation>Van már &apos;%1&apos; fájl!</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Window Manager</source>
        <translation>Ablakkezelő</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <source>Search...</source>
        <translation>Keresés...</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="59"/>
        <source>LXQt Modules</source>
        <translation>LXQt modulok</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="65"/>
        <source>Start</source>
        <translation>Indítás</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="72"/>
        <source>Stop</source>
        <translation>Leállítás</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="111"/>
        <source>Leave Session</source>
        <translation>Munkamenet elhagyása</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="117"/>
        <source>Ask for confirmation to leave session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ask confirmation to leave session</source>
        <translation type="vanished">Jóváhagyás az elhagyás előtt</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Alapbeállítások</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="137"/>
        <source>Select a window manager</source>
        <translation>Ablakkezelő választása</translation>
    </message>
</context>
<context>
    <name>DefaultApps</name>
    <message>
        <location filename="../defaultappspage.cpp" line="72"/>
        <source>Select a terminal emulator</source>
        <translation>Terminálemulátor választása</translation>
    </message>
    <message>
        <location filename="../defaultappspage.cpp" line="77"/>
        <source>Select a web browser</source>
        <translation>Webböngésző választása</translation>
    </message>
</context>
<context>
    <name>DefaultAppsPage</name>
    <message>
        <location filename="../defaultappspage.ui" line="23"/>
        <source>Default Applications</source>
        <translation>Alapértelmezett alkalmazások</translation>
    </message>
    <message>
        <location filename="../defaultappspage.ui" line="32"/>
        <source>Terminal Emulation:</source>
        <translation>Terminálemuláció:</translation>
    </message>
    <message>
        <location filename="../defaultappspage.ui" line="52"/>
        <location filename="../defaultappspage.ui" line="79"/>
        <source>Search...</source>
        <translation>Keresés…</translation>
    </message>
    <message>
        <location filename="../defaultappspage.ui" line="59"/>
        <source>Web Browser:</source>
        <translation>Webböngésző:</translation>
    </message>
</context>
<context>
    <name>EnvironmentPage</name>
    <message>
        <location filename="../environmentpage.ui" line="17"/>
        <source>Add</source>
        <translation>Hozzáadás</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="24"/>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="50"/>
        <source>Environment Variables (Advanced)</source>
        <translation>Környezeti változók (speciális)</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="61"/>
        <source>Variable Name</source>
        <translation>Változónév</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="66"/>
        <source>Value</source>
        <translation>Érték</translation>
    </message>
</context>
<context>
    <name>ModuleModel</name>
    <message>
        <location filename="../modulemodel.cpp" line="86"/>
        <source>Running</source>
        <translation>Futó</translation>
    </message>
</context>
<context>
    <name>SessionConfigWindow</name>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="44"/>
        <source>LXQt Session Settings</source>
        <translation>LXQt munkamenet-beállítás</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="47"/>
        <source>Basic Settings</source>
        <translation>Alapbeállítások</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="53"/>
        <source>Default Applications</source>
        <translation>Alapértelmezett alkalmazások</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="56"/>
        <source>Locations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="62"/>
        <source>Autostart</source>
        <translation>Automatikus indítás</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="68"/>
        <source>Environment (Advanced)</source>
        <translation>Környezet (speciális)</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="92"/>
        <source>Session Restart Required</source>
        <translation>A munkamenet újraindítandó</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="93"/>
        <source>Some settings will not take effect until the next log in.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You need to restart desktop session (lxqt-session) to reload settings. Use logout from the main menu.</source>
        <translation type="vanished">Újra kell indítania a munkamenetet (lxqt-session) a beállítások újratöltéséhez. Használja a főmenü kijelentkezés pontját.</translation>
    </message>
</context>
<context>
    <name>UserLocationsPage</name>
    <message>
        <location filename="../userlocationspage.cpp" line="99"/>
        <source>Locations for Personal Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="160"/>
        <source>LXQt Session Settings - Locations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="161"/>
        <source>An error ocurred while applying the settings for the %1 location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="177"/>
        <source>Choose Location</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserLocationsPrivate</name>
    <message>
        <location filename="../userlocationspage.cpp" line="59"/>
        <source>Desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="60"/>
        <source>Downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="61"/>
        <source>Templates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="62"/>
        <source>Public Share</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="63"/>
        <source>Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="64"/>
        <source>Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="65"/>
        <source>Pictures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="66"/>
        <source>Videos</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
